from __future__ import annotations

from pathlib import Path
from typing import TYPE_CHECKING

import polars as pl
from polars.plugins import register_plugin_function
__version__ = "0.2.0.dev0"

if TYPE_CHECKING:
    from polars_phonetics.typing import IntoExprColumn

LIB = Path(__file__).parent


def dmetaphone(expr: IntoExprColumn) -> pl.Expr:
    return register_plugin_function(
        args=[expr],
        plugin_path=LIB,
        function_name="dmetaphone",
        is_elementwise=True,
    )

def soundex(expr: IntoExprColumn) -> pl.Expr:
    return register_plugin_function(
        args=[expr],
        plugin_path=LIB,
        function_name="soundex",
        is_elementwise=True,
    )

def metaphone(expr: IntoExprColumn) -> pl.Expr:
    return register_plugin_function(
        args=[expr],
        plugin_path=LIB,
        function_name="metaphone",
        is_elementwise=True,
    )

def nysiis(expr: IntoExprColumn) -> pl.Expr:
    return register_plugin_function(
        args=[expr],
        plugin_path=LIB,
        function_name="nysiis",
        is_elementwise=True,
    )





import polars as pl
from polars_phonetics import dmetaphone
from polars.testing import assert_frame_equal


def test_dmetaphone():
    df = pl.DataFrame(
        {
            "words": ["hello", "this", "is", "the", "phonetics", "plugin", "in", "polars", None],
        }
    )
    result = df.with_columns(dmetaphone=dmetaphone("words"))

    expected_df = pl.DataFrame(
        {
            "words": ["hello", "this", "is", "the", "phonetics", "plugin", "in", "polars", None],
            "dmetaphone": ["[HL, HL]", "[0S, TS]", "[AS, AS]", "[0, T]", "[FNTK, FNTK]", "[PLJN, PLKN]", "[AN, AN]", "[PLRS, PLRS]", None],
        }
    )

    assert_frame_equal(result, expected_df)


import polars as pl
from polars_phonetics import dmetaphone, soundex, metaphone, nysiis


df = pl.DataFrame(
    {
        "words": ["hello", "this", "is", "the", "phonetics", "plugin", "in", "polars", None],
    }
)
result = df.with_columns(
    dmetaphone=dmetaphone("words"),
    soundex=soundex("words"),
    metaphone=metaphone("words"),
    nysiis=nysiis("words"),
)

with pl.Config() as cfg:
    cfg.set_tbl_cols(-1)
    cfg.set_tbl_rows(100)
    print(result)


import polars as pl
from polars_phonetics import metaphone
from polars.testing import assert_frame_equal


def test_metaphone():
    df = pl.DataFrame(
        {
            "words": ["hello", "this", "is", "the", "phonetics", "plugin", "in", "polars", None],
        }
    )
    result = df.with_columns(metaphone=metaphone("words"))

    expected_df = pl.DataFrame(
        {
            "words": ["hello", "this", "is", "the", "phonetics", "plugin", "in", "polars", None],
            "metaphone": ['HL', '0S', 'IS', '0', 'FNTK', 'PLJN', 'IN', 'PLRS', None],
        }
    )

    assert_frame_equal(result, expected_df)


import polars as pl
from polars_phonetics import soundex
from polars.testing import assert_frame_equal


def test_soundex():
    df = pl.DataFrame(
        {
            "words": ["hello", "this", "is", "the", "phonetics", "plugin", "in", "polars", None],
        }
    )
    result = df.with_columns(soundex=soundex("words"))

    expected_df = pl.DataFrame(
        {
            "words": ["hello", "this", "is", "the", "phonetics", "plugin", "in", "polars", None],
            "soundex": ['H400', 'T200', 'I200', 'T000', 'P532', 'P425', 'I500', 'P462', None],
        }
    )

    assert_frame_equal(result, expected_df)


import polars as pl
from polars_phonetics import nysiis
from polars.testing import assert_frame_equal


def test_nysiis():
    df = pl.DataFrame(
        {
            "words": ["hello", "this", "is", "the", "phonetics", "plugin", "in", "polars", None],
        }
    )
    result = df.with_columns(nysiis=nysiis("words"))

    expected_df = pl.DataFrame(
        {
            "words": ["hello", "this", "is", "the", "phonetics", "plugin", "in", "polars", None],
            "nysiis": ['HAL', 'T', 'I', 'T', 'FANATA', 'PLAGAN', 'IN', 'PALAR', None],
        }
    )

    assert_frame_equal(result, expected_df)